@@ -110,9 +110,6 @@ class skl_graph_t(ntkx.MultiGraph):
         "direction_style",
         "label_styles",
     )
-
-    # TODO: use styles in all functions, not just plotexplicity (partially done for networkx)
-
     domain_shape: tuple[int, ...]
     n_components: int
     n_s_nodes: int
@@ -127,7 +124,7 @@ class skl_graph_t(ntkx.MultiGraph):
     def __init__(self) -> None:
         """"""
         super().__init__()
-        for slot in self.__class__.__slots__:
+        for slot in skl_graph_t.__slots__:
             setattr(self, slot, None)
 
     @classmethod
@@ -493,10 +490,10 @@ class skl_graph_t(ntkx.MultiGraph):
         """
         if node is not None:
             styles = node_style_t.NewFromUnstructured(node)
-            if isinstance(node, tuple):  # node_style_raw_h
-                self.node_styles = styles
-            else:
+            if isinstance(node, dict):  # node_styles_raw_h
                 self.node_styles.update(styles)
+            else:
+                self.node_styles = styles
             if None not in self.node_styles:
                 # Should never happen, but just in case...
                 raise ValueError(
