@@ -105,8 +105,6 @@ def SKLMapFromObjectMap(
     array_t | tuple[array_t, array_t]
 
     """
-    # TODO: check doc of skmp.thin and skmp.skeletonize_3d
-    # TODO: check returned dtype of thin/skeletonize, make returned dtype coherent if needed
     if object_map.ndim == 2:
         # Documentation says it removes every pixel up to breaking connectivity
         Skeletonized = skmp.thin
@@ -116,12 +114,9 @@ def SKLMapFromObjectMap(
     else:
         raise ValueError(f"{object_map.ndim}: Invalid map dimension; Expected: 2 or 3")
 
-    output = Skeletonized(object_map)
-    # In case the skeleton is marked with 255, which converts to -1 in int8
-    output[output > 1] = 1
-    output = output.astype(nmpy.int8, copy=False)
+    output = Skeletonized(object_map).astype(nmpy.bool_, copy=False)
     if object_map.ndim == 3:
-        TurnThickSKLMapIntoSKLMap(output)
+        SKLMapFromThickVersion(output, in_place=True)
 
     if with_width:
         return output, SkeletonWidthMapFromObjectMap(object_map)
@@ -152,24 +147,14 @@ _CROSS_3x3x3 = nmpy.array((_CENTER_3x3, _CROSS_3x3, _CENTER_3x3), dtype=nmpy.uin
 _CROSS_FOR_DIM = (None, None, _CROSS_3x3, _CROSS_3x3x3)
 
 
-def TurnThickSKLMapIntoSKLMap(skl_map: array_t, /) -> None:
+def SKLMapFromThickVersion(
+    skl_map: array_t, /, *, in_place: bool = False, should_only_check: bool = False
+) -> array_t | bool | None:
     """Removes all sites (pixels or voxels) that do not break the skeleton connectivity (in the weakest sense) or
     shorten a branch.
 
-    Removing a site means setting it to zero.
-
     Works for multi-skeletons.
-
-    Parameters
-    ----------
-    skl_map : numpy.ndarray
-
-    Returns
-    -------
-    None
-
     """
-    # TODO: check removal of inner pixels/voxels that creates loops. Example: a cross made of 5 pixels.
     dtype = skl_map.dtype
     is_boolean = nmpy.issubdtype(dtype, nmpy.bool_)
     if not (is_boolean or nmpy.issubdtype(dtype, nmpy.integer)):
@@ -188,60 +173,96 @@ def TurnThickSKLMapIntoSKLMap(skl_map: array_t, /) -> None:
             )
         min_value, max_value = unique_values
 
-    cross = _CROSS_FOR_DIM[skl_map.ndim]
-    LabeledMap = tymp.LABELING_FCT_FOR_DIM[skl_map.ndim]
+    skl_dimension = skl_map.ndim
     background_label = tymp.TMapBackgroundLabel(skl_map)
-    padded_map = nmpy.pad(skl_map, 1)
+    patch_center = skl_dimension * (1,)
+    cross = _CROSS_FOR_DIM[skl_dimension]
+    padded_thinned = nmpy.pad(skl_map, 1)
+    LabeledMap = tymp.LABELING_FCT_FOR_DIM[skl_dimension]
 
-    def FixLocalMap_n(
-        _topo_map: array_t,
+    def _DoFixPatches(
+        _tpy_map: array_t,
         _n_neighbors: int,
         /,
     ) -> bool:
         """"""
-        skel_has_been_modified_ = False
+        _skel_has_been_modified = False
 
-        center = padded_map.ndim * (1,)
-        for coords in zip(*nmpy.where(_topo_map == _n_neighbors)):
-            lm_slices = tuple(slice(coord - 1, coord + 2) for coord in coords)
-            local_map = padded_map[lm_slices]
-            local_part_map = _topo_map[lm_slices]
-            if (local_part_map[cross] == background_label).any():
-                local_map[center] = min_value
+        for where in zip(*nmpy.where(_tpy_map == _n_neighbors)):
+            patch_slices = tuple(slice(coord - 1, coord + 2) for coord in where)
+            tpy_patch = _tpy_map[patch_slices]
+            if nmpy.any(tpy_patch[cross] == background_label):
+                patch = padded_thinned[patch_slices]
+                patch[patch_center] = min_value
 
-                _, n_components = LabeledMap(local_map)
+                _, n_components = LabeledMap(patch)
                 if n_components == 1:
-                    skel_has_been_modified_ = True
+                    _skel_has_been_modified = True
                 else:
-                    local_map[center] = max_value
+                    patch[patch_center] = max_value
 
-        return skel_has_been_modified_
+        return _skel_has_been_modified
 
+    def _JustCheckPatches(
+        _tpy_map: array_t,
+        _n_neighbors: int,
+        /,
+    ) -> bool:
+        """"""
+        for where in zip(*nmpy.where(_tpy_map == _n_neighbors)):
+            patch_slices = tuple(slice(coord - 1, coord + 2) for coord in where)
+            tpy_patch = _tpy_map[patch_slices]
+            if nmpy.any(tpy_patch[cross] == background_label):
+                patch = padded_thinned[patch_slices]
+                patch[patch_center] = min_value
+
+                _, n_components = LabeledMap(patch)
+                if n_components == 1:
+                    return True
+                else:
+                    patch[patch_center] = max_value
+
+        return False
+
+    if should_only_check:
+        _FixPatches = _JustCheckPatches
+    else:
+        _FixPatches = _DoFixPatches
     excluded_n_neighbors = {
         0,
         1,
-        2 * skl_map.ndim,
+        2 * skl_dimension,
         background_label,
     }
     skel_has_been_modified = True
     while skel_has_been_modified:
         skel_has_been_modified = False
 
-        topo_map = tymp.TopologyMapOfMap(padded_map, full_connectivity=False)
-        included_n_neighbors = set(nmpy.unique(topo_map)).difference(
+        tpy_map = tymp.TopologyMapOfMap(padded_thinned, full_connectivity=False)
+        included_n_neighbors = set(nmpy.unique(tpy_map)).difference(
             excluded_n_neighbors
         )
 
         for n_neighbors in sorted(included_n_neighbors, reverse=True):
-            skel_has_been_modified = skel_has_been_modified or FixLocalMap_n(
-                topo_map,
+            skel_has_been_modified = skel_has_been_modified or _FixPatches(
+                tpy_map,
                 n_neighbors,
             )
+            if should_only_check and skel_has_been_modified:
+                return False
 
-    if skl_map.ndim == 2:
-        skl_map[:, :] = padded_map[1:-1, 1:-1]
+    if should_only_check:
+        return True
+
+    if skl_dimension == 2:
+        thinned = padded_thinned[1:-1, 1:-1]
     else:
-        skl_map[:, :, :] = padded_map[1:-1, 1:-1, 1:-1]
+        thinned = padded_thinned[1:-1, 1:-1, 1:-1]
+
+    if in_place:
+        nmpy.copyto(skl_map, thinned)
+    else:
+        return thinned
 
 
 def PruneSKLMapBasedOnWidth(
@@ -264,8 +285,8 @@ def PruneSKLMapBasedOnWidth(
 
     """
     while True:
-        topo_map = tymp.TopologyMapOfMap(skl_map)
-        end_positions = nmpy.where(topo_map == 1)
+        tpy_map = tymp.TopologyMapOfMap(skl_map)
+        end_positions = nmpy.where(tpy_map == 1)
         distances = width_map[end_positions]
 
         tiny_distances = distances < min_width
