@@ -162,7 +162,7 @@ class edge_t(raw_edge_t):
             if as_curve is None:
                 if self.n_sites > 1:
                     sites_as_array = nmpy.array(self.sites)
-                    derivatives = nmpy.diff(sites_as_array, axis=1)
+                    derivatives = nmpy.diff(sites_as_array, axis=1).astype(nmpy.float64)
                     norms = nmpy.linalg.norm(derivatives, axis=0, keepdims=True)
                     derivatives /= norms
                     last = derivatives[:, -1][:, None]
@@ -182,15 +182,24 @@ class edge_t(raw_edge_t):
         return self._cache[cache_entry]
 
     def DirectionChanges(self) -> array_t:
-        """"""
+        """
+        2-D: determinant of consecutive directions, normalized by arc length differences.
+        3-D: "signed" norm of the cross product of consecutive directions, normalized by arc length differences.
+        """
         cache_entry = self.DirectionChanges.__name__
 
         if cache_entry not in self._cache:
+            if self.dim == 2:
+                Determinant = lambda _vct, _ref: (nmpy.linalg.det(_vct), _ref)
+            else:
+                Determinant = _SignedCrossProductNorm
+
             _, arc_lengths, directions = self.Directions()
             determinants = nmpy.empty((directions.shape[1] - 1), dtype=nmpy.float64)
+            reference = None
             for c_idx in range(directions.shape[1] - 1):
-                determinants[c_idx] = nmpy.linalg.det(
-                    directions[:, c_idx : (c_idx + 2)]
+                determinants[c_idx], reference = Determinant(
+                    directions[:, c_idx : (c_idx + 2)], reference
                 )
             determinants /= arc_lengths[1:]
 
@@ -633,3 +642,17 @@ def _PchipInterpolator(
             return output
 
     raise RuntimeError("Should never happen. Please contact developer.")
+
+
+def _SignedCrossProductNorm(
+    vectors: array_t, reference: array_t | None, /
+) -> tuple[float, array_t]:
+    """"""
+    product = nmpy.cross(vectors[:, 0], vectors[:, 1])
+    if reference is None:
+        reference = product
+        sign = 1.0
+    else:
+        sign = nmpy.dot(product, reference)
+
+    return (sign * nmpy.linalg.norm(product)).item(), reference
